@@ -4,10 +4,10 @@
 ;;
 ;; Author: Bozhidar Batsov <bozhidar@batsov.dev>
 ;; URL: https://github.com/clojure-emacs/clojure-mode
-;; Package-Version: 20260212.1414
-;; Package-Revision: b88e25b0d7ab
+;; Package-Version: 20260219.2144
+;; Package-Revision: b9a648b14848
 ;; Keywords: languages, lisp
-;; Package-Requires: ((clojure-mode "3.0"))
+;; Package-Requires: ((clojure-mode "5.21.0"))
 
 ;; This file is not part of GNU Emacs.
 
@@ -44,8 +44,10 @@
 (defvar clojure-built-in-vars
   '(
     ;; clojure.core
+    "abs"
     "accessor"
     "aclone"
+    "add-tap"
     "agent"
     "agent-errors"
     "aget"
@@ -157,7 +159,6 @@
     "dissoc!"
     "distinct"
     "distinct?"
-    "doc"
     "double"
     "double?"
     "double-array"
@@ -186,7 +187,6 @@
     "filter"
     "filterv"
     "find"
-    "find-doc"
     "find-ns"
     "find-keyword"
     "find-var"
@@ -215,7 +215,7 @@
     "get-thread-bindings"
     "get-validator"
     "group-by"
-    "halt-when?"
+    "halt-when"
     "hash"
     "hash-map"
     "hash-ordered-coll"
@@ -227,6 +227,7 @@
     "indexed?"
     "ifn?"
     "inc"
+    "infinite?"
     "init-proxy"
     "instance?"
     "inst-ms"
@@ -242,6 +243,7 @@
     "into-array"
     "ints"
     "isa?"
+    "iteration"
     "iterate"
     "iterator-seq"
     "juxt"
@@ -285,6 +287,7 @@
     "mix-collection-hash"
     "mod"
     "name"
+    "NaN?"
     "namespace"
     "nat-int?"
     "neg-int?"
@@ -318,10 +321,16 @@
     "object-array"
     "odd?"
     "parents"
+    "parse-boolean"
+    "parse-double"
+    "parse-long"
+    "parse-uuid"
     "partial"
     "partition"
     "partition-all"
     "partition-by"
+    "partitionv"
+    "partitionv-all"
     "pcalls"
     "peek"
     "persistent!"
@@ -362,6 +371,7 @@
     "rand"
     "rand-int"
     "rand-nth"
+    "random-uuid"
     "range"
     "ratio?"
     "rational?"
@@ -393,6 +403,7 @@
     "remove-all-methods"
     "remove-method"
     "remove-ns"
+    "remove-tap"
     "remove-watch"
     "repeat"
     "repeatedly"
@@ -434,7 +445,7 @@
     "shorts"
     "shuffle"
     "shutdown-agents"
-    "simple-indent?"
+    "simple-ident?"
     "simple-keyword?"
     "simple-symbol?"
     "slurp"
@@ -448,15 +459,16 @@
     "sorted-set"
     "sorted-set-by"
     "sorted?"
-    "special-form-anchor"
     "special-symbol?"
-    "specify"
-    "specify!"
     "spit"
     "split-at"
     "split-with"
+    "splitv-at"
     "str"
-    "stream?"
+    "stream-into!"
+    "stream-reduce!"
+    "stream-seq!"
+    "stream-transduce!"
     "string?"
     "struct"
     "struct-map"
@@ -468,11 +480,11 @@
     "swap-vals!"
     "symbol"
     "symbol?"
-    "syntax-symbol-anchor"
     "take"
     "take-last"
     "take-nth"
     "take-while"
+    "tap>"
     "test"
     "the-ns"
     "thread-bound?"
@@ -503,15 +515,17 @@
     "unchecked-remainder"
     "unchecked-remainder-int"
     "unchecked-short"
-    "unchecked-subtract-int"
     "unchecked-subtract"
+    "unchecked-subtract-int"
     "underive"
     "unsigned-bit-shift-right"
     "unquote"
     "unquote-splicing"
     "update"
     "update-in"
+    "update-keys"
     "update-proxy"
+    "update-vals"
     "uri?"
     "use"
     "uuid?"
@@ -542,17 +556,42 @@
     "is-leaf"
     "list-model"
     "list-provider"
+    "old-table-model"
+    "table-model"
+    "tree-model"
 
     ;; clojure.main
+    "demunge"
+    "err->msg"
+    "ex-str"
+    "ex-triage"
     "load-script"
     "main"
+    "renumbering-read"
     "repl"
     "repl-caught"
     "repl-exception"
     "repl-prompt"
     "repl-read"
+    "repl-requires"
+    "report-error"
+    "root-cause"
     "skip-if-eol"
     "skip-whitespace"
+    "stack-element-str"
+    "with-read-known"
+
+    ;; clojure.repl
+    "apropos"
+    "dir"
+    "dir-fn"
+    "doc"
+    "find-doc"
+    "pst"
+    "set-break-handler!"
+    "source"
+    "source-fn"
+    "thread-stopper"
 
     ;; clojure.set
     "difference"
@@ -564,6 +603,8 @@
     "rename"
     "rename-keys"
     "select"
+    "subset?"
+    "superset?"
     "union"
 
     ;; clojure.stacktrace
@@ -572,6 +613,7 @@
     "print-stack-trace"
     "print-throwable"
     "print-trace-element"
+    "root-cause"
 
     ;; clojure.template
     "do-template"
@@ -583,16 +625,21 @@
     "assert-expr"
     "assert-predicate"
     "compose-fixtures"
-    "deftest"
-    "deftest-"
+    "do-report"
     "file-position"
     "function?"
     "get-possibly-unbound-var"
     "inc-report-counter"
     "is"
     "join-fixtures"
+    "print-tap-diagnostic"
+    "print-tap-fail"
+    "print-tap-pass"
+    "print-tap-plan"
     "report"
     "run-all-tests"
+    "run-test"
+    "run-test-var"
     "run-tests"
     "set-test"
     "successful?"
@@ -605,6 +652,8 @@
     "testing-vars-str"
     "try-expr"
     "use-fixtures"
+    "with-junit-output"
+    "with-tap-output"
     "with-test"
     "with-test-out"
 
@@ -624,9 +673,15 @@
     "attrs"
     "content"
     "content-handler"
+    "disable-external-entities"
     "element"
     "emit"
     "emit-element"
+    "parse"
+    "sax-parser"
+    "startparse-sax"
+    "startparse-sax-safe"
+    "tag"
 
     ;; clojure.zip
     "append-child"
@@ -654,6 +709,9 @@
     "root"
     "seq-zip"
     "up"
+    "vector-zip"
+    "xml-zip"
+    "zipper"
     )
   )
 
